# Peplum ChangeLog

## v0.1.0

**Released: 2025-01-25**

- Initial release.

## v0.0.1

**Released: 2025-01-14**

- Initial placeholder package to test that the name is available in PyPI.

[//]: # (ChangeLog.md ends here)
